*-- Put order information for several customers into an Excel worksheet
*-- Change the LoopCounter constant to change the number of customers
*-- entered into Excel - Shows some new methods of V1.0.2 and V1.0.3

*-- This is a modified version from Microsoft Office Automation with VFP.
*-- for use with the DLL Class.

*-- Note this code sometimes can take some time to run, this is due to
*-- the PageSetup code. 

RELEASE ALL LIKE o*

#INCLUDE "Excel9.h"

#DEFINE autoIn2Pts			72
#DEFINE LoopCounter			3			

*-- This program will take longer if you increase the LoopCounter

LOCAL oExcel, oSheet, oRange
LOCAL lnX, lnI

LOCAL ARRAY laProps[1,2]

*-- Lets open the Data
CLOSE DATA
OPEN DATABASE _SAMPLES + "\TASTRADE\DATA\TasTrade"
USE Customer IN 0 
USE "Order History" ALIAS OrderHistory IN 0

*-- Create the Object
oExcel = CREATEOBJECT('OfficeClass.clsExcel')

oExcel.BuildExcelBook(1)		&& Add 1 Work Sheet.

*-- Lets add some styles to the WorkBook.
*-- New Method to Allow multiple properties to be set at once in (V1.0.3)
*-- E.g. Array [x,1] = "Style Name", [x,2] = "Property", [x,3] = Value
WITH oExcel
	.BuildStyle("Bold","Font.Bold",.T.)
	.BuildStyle("Bold","Font.Size",12)
	.BuildStyle("Bold","HorizontalAlignment",xlHAlignCenter)
	.BuildStyle("Bold","VerticalAlignment",xlVAlignCenter)
	.BuildStyle("Bold","WrapText",.T.)
ENDWITH

SELECT OrderHistory

FOR lnI = 1 TO LoopCounter
	ReQuery()
	
	oSheet = oExcel.GetActiveSheet()	&& Return the Active Sheet Object	
	
	WITH oExcel
		.RenameSheet(Customer.Customer_ID)
		.BuildSheet("A2",Customer.Company_Name)
		.ConvertStringToArray("Order Number,Date:10,Amount")
		.BuildLineFromArray("A5")		
		oRange = .GetSelection("A6:C6")
	ENDWITH
	
	SCAN
		WITH oRange
			.Columns[1].Value = Order_Id
			.Columns[2].Value = Order_Date
			.Columns[3].Value = Ord_Total
		ENDWITH
		oRange = oRange.Offset(1,0)
	ENDSCAN
	
	nLastRow = oRange.Row
	cLastRow = ALLTRIM(STR(nLastRow))
	
	WITH oSheet
		.Cells[ nLastRow, 1 ] = "Total"
		.Cells[ nLastRow, 3 ].Formula = "=SUM(C6:C"+ALLTRIM(STR(nLastRow-1))+")"
	ENDWITH
	
	*-- Start Formatting
	WITH oExcel
		.SetStyle("A5:C5","Bold")
		.DrawLine("A5:C5","B","xlContinuous",RGB(255,0,0))
		.SetStyle("A" + cLastRow,"Bold")
		.DrawLine("A" + cLastRow + ":C" + cLastRow,"T","xlContinuous")
		.SetStyle("A2","Bold")
		.CellAlignment("A2:C2","HAlignCenter")
		.SetCell("B6:B" + cLastRow,"NumberFormat","Dd-Mmm-YYY")
		oRange = .GetSelection("A5:C" + cLastRow)
		WITH oRange
			.Columns.AutoFit()
			FOR lnX = 1 TO 3
				.Columns[lnX].ColumnWidth = .Columns[lnX].ColumnWidth + 1
			ENDFOR
		ENDWITH		

*--			*-- Single Property at a time.
*--			.SetWorkSheet("PageSetup.Orientation"       ,xlPortrait)
*--			.SetWorkSheet("PageSetup.FitToPagesTall"    ,1)
*--			.SetWorkSheet("PageSetup.FitToPagesWide"    ,1)
*--			.SetWorkSheet("PageSetup.CenterHorizontally",.T.)
*--			.SetWorkSheet("PageSetup.CenterVertically"  ,.T.)
*--			.SetWorkSheet("PageSetup.TopMargin"         , 1.0 * autoIn2Pts)
*--			.SetWorkSheet("PageSetup.BottomMargin"      , 1.0 * autoIn2Pts)
*--			.SetWorkSheet("PageSetup.LeftMargin"        , 1.5 * autoIn2Pts)
*--			.SetWorkSheet("PageSetup.RightMargin"       , 1.5 * autoIn2Pts)
*--			.SetWorkSheet("PageSetup.HeaderMargin"      , 0.5 * autoIn2Pts)
*--			.SetWorkSheet("PageSetup.FooterMargin"      , 0.5 * autoIn2Pts)
*--			.SetWorkSheet("PageSetup.LeftHeader"        , "TasTrade Client ID &A")
*--			.SetWorkSheet("PageSetup.RightHeader"       , "Page &P of &N")
*--			.SetWorkSheet("PageSetup.RightFooter"       , "Printed on &D")

		*-- New Way
		.BuildPageSetup("PageSetup.Orientation"       ,xlPortrait)
		.BuildPageSetup("PageSetup.FitToPagesTall"    ,1)
		.BuildPageSetup("PageSetup.FitToPagesWide"    ,1)
		.BuildPageSetup("PageSetup.CenterHorizontally",.T.)
		.BuildPageSetup("PageSetup.CenterVertically"  ,.T.)
		.BuildPageSetup("PageSetup.TopMargin"         , 1.0 * autoIn2Pts)
		.BuildPageSetup("PageSetup.BottomMargin"      , 1.0 * autoIn2Pts)
		.BuildPageSetup("PageSetup.LeftMargin"        , 1.5 * autoIn2Pts)
		.BuildPageSetup("PageSetup.RightMargin"       , 1.5 * autoIn2Pts)
		.BuildPageSetup("PageSetup.HeaderMargin"      , 0.5 * autoIn2Pts)
		.BuildPageSetup("PageSetup.FooterMargin"      , 0.5 * autoIn2Pts)
		.BuildPageSetup("PageSetup.LeftHeader"        , "TasTrade Client ID &A")
		.BuildPageSetup("PageSetup.RightHeader"       , "Page &P of &N")
		.BuildPageSetup("PageSetup.RightFooter"       , "Printed on &D")
*-- Or you could build an array containing these and pass this to the method.
*--			DIMENSION laProp[2,2]
*--			laProp[1,1] = "PageSetup.Orientation"
*--			laProp[1,2] = xlPortrait
*--			laProp[2,1] = "PageSetup.CenterHorizontally"
*--			laProp[2,2] = .T.
*--			.BuildPageSetup("ARRAY",@laProp)		

		.SetPageSetup()
	ENDWITH
	IF lnI <> LoopCounter
		oExcel.AddSheet("Before",1)	&& Always add at the start
	ENDIF
	SKIP IN Customer
ENDFOR

oExcel.ShowExcel()
oExcel.PrintPreview()
*oExcel.SaveWorkBook("XLSample.XLS")
*oExcel.CloseExcel()
oExcel = .NULL.
USE IN OrderHistory
USE IN Customer
