RELEASE ALL LIKE o*

*-- Example for Creating PivotTable Data.
*-- Now Lets Start Adding a PivotTable.

LOCAL oExcel, oRange, lcLine, oSheet
LOCAL oSource, oDest, oPivot

#INCLUDE "Excel9.h" 

OPEN DATABASE (_SAMPLES + "\TasTrade\Data\TasTrade")

SELECT Customer.Company_Name, Customer.Country, ;
	   CMONTH(Orders.Order_Date) AS Order_Month, ;
       YEAR(Orders.Order_Date) AS Order_Year, ;
       Category.Category_Name, Products.Product_Name, ;
	   Order_Line_Items.Quantity, Order_Line_Items.Unit_Price * Order_Line_Items.Quantity AS Total_Price;
	FROM Orders, Order_Line_Items, Customer, Products, Category ;
	WHERE Order_Line_Items.Order_ID = Orders.Order_ID AND ;
	      Orders.Customer_ID = Customer.Customer_ID   AND ;
	      Order_Line_Items.Product_ID = Products.Product_ID  AND ;
	      Products.Category_ID = Category.Category_ID ;
	INTO CURSOR Pivot

lcLine = ALLTRIM(STR(_TALLY + 1 ))

COPY TO (CURDIR() + "Pivot") TYPE XL5

oExcel = CREATEOBJECT('OfficeClass.clsExcel')

WITH oExcel
	.OpenFile( SYS(5) + CURDIR() + "Pivot.XLS" )
	.ShowExcel()
	oRange = .GetSelection(1,"A1:H" + lcLine)
	oRange.Columns.AutoFit()

	*-- This is the Pivot Table 
	oSource = .GetSelection(1,"A1:H2822")
	oDest   = .GetSelection(1,"J1")
	oSheet  = .GetActiveSheet()
	oPivot  = oSheet.PivotTableWizard(xlDatabase,oSource,oDest,"SalesAnalysis",.T.,.T.)
	
	*-- As an example, set the rows to the country field and the columns 
	*-- to the category name with the following code:
	oPivot.AddFields("country", "category_name")
	
	*-- To summarize the quantity field, give the following commands:
	oPivot.PivotFields["Quantity"].Orientation = xlDataField

	
	*-- Hide some of the Countries in the Pivot Table
	*-- Short Way
	FOR EACH oItem IN oPivot.PivotFields("category_name").PivotItems
		IF NOT oItem.Name $ ("Beverages Confections")
			oItem.Visible = .F.
		ENDIF
	ENDFOR

	*-- Remove some of the Category names from the table.
	*-- Long Way
*--		WITH oPivot.PivotFields("category_name")
*--			.PivotItems("Condiments").Visible     = .F.
*--			.PivotItems("Dairy Products").Visible = .F.
*--			.PivotItems("Grains/Cereals").Visible = .F.
*--			.PivotItems("Meat/Poultry").Visible   = .F.
*--			.PivotItems("Produce").Visible        = .F.
*--			.PivotItems("Seafood").Visible        = .F.
*--		ENDWITH

	*-- Hide some of the Countrys 
	*-- Short Way
	FOR EACH oItem IN oPivot.PivotFields("country").PivotItems
		IF NOT oItem.Name $ ("Canada Mexico USA")
			oItem.Visible = .F.
		ENDIF
	ENDFOR
	
	*-- Long Way
*--		WITH oPivot.PivotFields("country")
*--			.PivotItems("Argentina").Visible   = .F.
*--			.PivotItems("Austria").Visible     = .F.
*--			.PivotItems("Belgium").Visible     = .F.
*--			.PivotItems("Brazil").Visible      = .F.
*--			.PivotItems("Denmark").Visible     = .F.
*--			.PivotItems("Finland").Visible     = .F.
*--			.PivotItems("France").Visible      = .F.
*--			.PivotItems("Germany").Visible     = .F.
*--			.PivotItems("Ireland").Visible     = .F.
*--			.PivotItems("Italy").Visible       = .F.
*--			.PivotItems("Norway").Visible      = .F.
*--			.PivotItems("Poland").Visible      = .F.
*--			.PivotItems("Portugal").Visible    = .F.
*--			.PivotItems("Spain").Visible       = .F.
*--			.PivotItems("Sweden").Visible      = .F.
*--			.PivotItems("Switzerland").Visible = .F.
*--			.PivotItems("UK").Visible          = .F.
*--			.PivotItems("Venezuela").Visible   = .F.
*--		ENDWITH

		*-- Lets get a little more complicated with the PivotTable. 
		*-- To make this PivotTable summarize the Total_Price field, use the following:
		oPivot.PivotFields["Total_Price"].Orientation = xlDataField

		*-- Changing the numeric format to currency works like this:
		oPivot.PivotFields["Sum of Total_Price"].NumberFormat = "$###,###,###.#0"

		*-- The code to add a third summary field and set it to the average 
		*-- of the Total_Price field is as follows:
		*-- Add another Total_Price summary field
		oPivot.PivotFields["Total_Price"].Orientation = xlDataField
		*-- Change its name
		oPivot.PivotFields["Sum of Total_Price2"].Name = "Average Total Sale"
		*-- Set the formula to average the data, rather than sum the data
		oPivot.PivotFields["Average Total Sale"].Function = xlAverage
		*-- Format it so the numbers look like currency
		oPivot.PivotFields["Average Total Sale"].NumberFormat = "$###,###,###.#0"

		*-- Now, to really see the power of PivotTables, you can add a second RowField. 
		*-- Whats the purpose of a second field? To see each countrys sales broken down by year. 
		*-- A pictures worth a thousand words here; the next line of code adds the Order_Year field 
		*-- as another RowField and combines with the previous examples to produce the following output.
		oPivot.PivotFields["Order_Year"].Orientation = xlRowField

ENDWITH

STORE .NULL. TO oSource, oDest, oSheet, oPivot, ;
				oRange , oExcel 

CLOSE DATA ALL
