*-- Modified Version from VFP with Office book,
*-- to work with the OfficeClass.dll
*-- PivotTable Example

* Clean out any existing references to servers.
* This prevents memory loss to leftover instances.

RELEASE ALL LIKE o*

* For demonstration purposes, make certain objects
* available after this program executes.

LOCAL oExcel , oRange, oSheet, lcLogo
LOCAL oSource, oDest , oPivot, lnI
LOCAL oShape , lcQty

#INCLUDE "Excel9.h"

#DEFINE msoShape24PointStar 95
#DEFINE autoIn2Pts 			72

CLOSE DATA
OPEN DATABASE (_SAMPLES + "\TasTrade\Data\TasTrade")

SELECT Customer.Company_Name, Customer.Country, ;
	   CMONTH(Orders.Order_Date) AS Order_Month, ;
	   YEAR(Orders.Order_Date) AS Order_Year, ;
	   Products.Product_Name, Order_Line_Items.Quantity, ;
	   Order_Line_Items.Unit_Price * Order_Line_Items.Quantity AS Total_Price;
	FROM Orders, Order_Line_Items, Customer, Products ;
	WHERE Order_Line_Items.Order_ID   = Orders.Order_ID      AND ;
	      Orders.Customer_ID          = Customer.Customer_ID AND ;
	      Order_Line_Items.Product_ID = Products.Product_ID  AND ;
	      ALLTRIM(Products.Category_ID)= "2" ; 
	INTO CURSOR Pivot

COPY TO (CURDIR() + "Pivot") TYPE XL5

oExcel = CREATEOBJECT('OfficeClass.clsExcel')

* Open the workbook, and best-fit all the columns.
* Ensure there are two sheets: Pivot for the data
* and another for the "presentation"

WITH oExcel	
	.OpenFile( SYS(5)+CURDIR() + "Pivot.xls")
	oRange = .GetSelection(1,"A1:G310")
	oRange.Columns.AutoFit()
	.ShowExcel()
	.AddSheet("BEFORE",1,1)
	oSheet = .GetActiveSheet()
	oRange = .NULL.

	* On the presentation worksheet, add the logo and title
	WITH oSheet
		*-- Add the TasTrade Logo
		lcLogo = _SAMPLES + "\TasTrade\Bitmaps\TTradeSm.bmp"
		.Shapes.AddPicture(lcLogo,.T.,.T.,0.25 * autoIn2Pts, 0.25 * autoIn2Pts, 1.00 * autoIn2Pts, 1.00 * autoIn2Pts)
		
		*-- Title the WorkSheet
		oExcel.BuildSheet(1,"C2","Analysis for Mama's Raspberry Syrup","Arial:18:B")
	
		*-- Create a new PivotTable.
		oSource = oExcel.GetSelection(2,"A1:G" + ALLTRIM(STR(RECCOUNT("Pivot") + 1)))
		oDest   = oExcel.GetSelection(1,"C4")
		oPivot  = .PivotTableWizard(xlDatabase,oSource,oDest,"Analysis",.T.,.T.)
		WITH oPivot
			.AddFields("Product_Name","Order_Year")
			.PivotFields["Quantity"].Orientation = xlDataField
			*-- Nice Headings.
			.PivotFields["Product_Name"].Name    = "Product Name"
			.PivotFields["Order_Year"].Name      = "Year"
			.PivotFields["Sum of quantity"].Name = "Quantity Sold"
		ENDWITH

		*-- Format the columns a bit wider
		FOR lnI = 4 TO 8
			.Columns[ lnI ].ColumnWidth = 9
		ENDFOR
	ENDWITH
	
	*-- Find the break-even point with Goal Seek
	*-- Title
	.BuildSheet(1,"C21","Break-Even Analysis","Arial:10:B")
	*-- Revenue
	.BuildSheet(1,"C22","Price per Unit")
	.BuildSheet(1,"C23","Units Sold")
	.BuildSheet(1,"C24","Total Revenue")
	.BuildSheet(1,"C26","Cost per Unit")
	.BuildSheet(1,"C27","Marketing Fee")
	.Buildsheet(1,"C28","Total Costs")
	.BuildSheet(1,"C30","Profit")
		
	oRange = .GetSelection(1,"D22")
	WITH oRange
		.Name         = "UnitPrice"
		.Value        = 10
		.NumberFormat = "$###.00"
	ENDWITH	
	oRange = .GetSelection(1,"D23")
	WITH oRange
		.Name         = "UnitsSold"
		.Value        = 100
		.NumberFormat = "###.0"
	ENDWITH
	.DrawLine(1,"C23:D23","B","xlContinuous")

	oRange = .GetSelection(1,"D24")
	WITH oRange
		.Name         = "TotalRevenue"
		.Value        = "= UnitPrice * UnitsSold"
		.NumberFormat = "$##,###.00"
	ENDWITH
	
	*-- Costs
	oRange = .GetSelection(1,"D26")
	WITH oRange
		.Name  = "UnitCost"
		.Value = 7.23
	ENDWITH
	oRange = .GetSelection(1,"D27")
	WITH oRange
		.Name  = "MarketingFee"
		.Value = 500	
	ENDWITH
	.DrawLine(1,"C27:D27","B","xlContinuous")
	oRange = .GetSelection(1,"D28")
	WITH oRange
		.Name  = "TotalCost"
		.Value = "=(UnitCost * UnitsSold) + MarketingFee"
	ENDWITH
	oRange = .GetSelection(1,"D26:D30")
	oRange.NumberFormat = "$##,###.00"

	*-- Profit
	oRange = .GetSelection(1,"D30")
	WITH oRange
		.Name  = "Profit"
		.Value = "=TotalRevenue - TotalCost"
	ENDWITH

	*-- Perform the Goal Seek
	oSheet.Range["Profit"].GoalSeek(0,oSheet.Range["UnitsSold"])

	*-- Add the shape with text indicating how many need
	*-- to be sold to break even.
	oShape = oSheet.Shapes.AddShape(msoShape24PointStar, ;
						4.8 * autoIn2Pts, 3.5 * autoIn2Pts, ;
						2.0 * autoIn2Pts, 2.0 * autoIn2Pts)		
	
	lcQty = ALLTRIM(STR(oSheet.Range["UnitsSold"].Value))

	WITH oShape.TextFrame
		WITH .Characters
			.Text = "Sell " + lcQty + " units to break even"
			WITH .Font
				.Color = RGB(255,0,0)
				.Size  = 12
				.Bold  = .T.
			ENDWITH
		ENDWITH
		.HorizontalAlignment = xlHAlignCenter
		.VerticalAlignment = xlVAlignCenter
	ENDWITH		
	
	oRange  = .NULL.
	oShape  = .NULL.
	oSource = .NULL.
	oDest   = .NULL.
	oPivot  = .NULL.
ENDWITH

oSheet = .NULL.
oExcel = .NULL.

CLOSE DATA ALL